///////////////////////////////////////////////////////////////
// script name:    BomberHud (generated by VeCTeR's INGAME Editor)
// version:        1.0
// date:           2001/08/25
// author:         Rene Robichaud (\VeCTeR)
// email:          vecter_wp@hotmail.com
// description:    
//   For the pilot of the thundersword/havoc.      
//     hover: a toggle key that lets the bomber (havoc) maintain an 
//            set altitude.  This set altitude can be adjusted.
//            Keyboard key: 0
//     acceleration warning: if acceleration is above 2 kpm per second, and 
//            speed is above 150 kph, the alarm goes on.  Accelerations
//            of this nature occur when afterburning or heading towards
//            the ground ;)
//     low speed warning: if speed drops below 200 kph, this alarm will 
//            turn on.
//     altitude warning: if altitude rate of change is less than 20, 
//            a warning goes off to tell the pilot the bomber is heading
//            towards the ground fast!  Warning: since altitude agl (above
//            ground level) is the only way to mesure altitude, mountains
//            will set off this alarm.  
//     radar warning: the same as the compass warning, but is on the dash.
//     bomber sight: the same sight the bomber sees.  Put this sight on
//            the target and the bomber will have an easy job.
//     PilotHud help: f1 key
// The bomber and t/g have speed and altitude, the bomber has a bomb/alt 
// warning and a radar warning.
//    
// status: working
// performance: 2 separate schedule functions called (recursive, 200 ms 
//     each).  Doesn't demand much resources.
///////////////////////////////////////////////////////////////


$playerAngle = 0;
$playerAccel = 0;
$oldAlt = 0;
$oldSpd = 0;
$altDir = "E";
$spdDir = "E";
$count = 0;
$pilotHud = false;
$isStarted = false;
$node = "";


// alarms
$rdrAlarm = false;
$rdrToggle = true;
$statusAlarm = false;
$statusToggle = false;
$altAlarm = false;
$altToggle = true;
$spdAlarm = false;
$lowSpdAlarm = false; 
$spdToggle = true;
$bombAlarm = false;
$bombToggle = true;
$testAlarm = false;

$yellowAlertColor = "40 247 113";
$redAlertColor = "255 103 50";

$display = true;

$autoPilot = false;
$apAdj = 0.005;
$autoPilotKey = "9";

$hover = false;
$hoverTimer = 0;
$hoverAlt = 0;
$hoverStartAlt = 0;
$hSpdSens = 25;       
$hPitchSens = 0.2;
$jetsFiring = false;
$hoverKey = "0";
$hoverUpKey = "=";
$hoverDownKey = "-";



package bomberHud {

// BOMBER OVERRIDES

function ClientCmdSetHudMode(%mode, %type, %node)
{ parent::clientCmdSetHudMode(%mode, %type, %node);

  if (%type $= "Bomber" || %type $= "HAPC")     
  { if (%node == 0)
      startBomber();
    else if (%node == 1)
    { startPassengerHud();
      startBombardierHud();
    }
    else
      startPassengerHud();
  }
  else if ($type $= "Bomber" || $type $= "HAPC")
  { if ($node == 0)
      endBomber();
    else if ($node == 1)
    { endBombardierHud();  
      endPassengerHud();
    }     
    else if ($node >= 1 && $node <= 6)
      endPassengerHud(); 
  }

  $type = %type;  
  $node = %node;
}


function startBomber()  
{ if (!$pref::BomberHud::showHelp)
  { clientCmdBottomPrint("\VeCTeR's BomberHud V1.0\nPress F1 in ThunderSword (or Havoc) for help\ntmail: \\VeCTeR, email: vecter_wp@hotmail.com", 10, 3);
    $pref::BomberHud::showHelp = "1";
  }
  passengerKeys.bindcmd( keyboard, $hoverKey, "hover();", "");
  passengerKeys.bindcmd( keyboard, $hoverUpKey, "hoverUp();", "");
  passengerKeys.bindcmd( keyboard, $hoverDownKey, "hoverDown();", "");
  passengerKeys.bindcmd( keyboard, $autoPilotKey, "autoPilot();", "");
  passengerKeys.bindcmd( keyboard, "f1", "pilotHudHelp();", "");
  
  if ($ladderSchedule != 0) cancel($ladderSchedule);
  	if ($hoverTimer != 0) cancel($hoverTimer);
  
	
	  if (!$bomberHudCreate)
	  {       
	    exec("gui/bomberHud.gui");
		    $bomberHudCreate = true;
  	}

  if ($hover)
  { $hover = false;  
    hover();
  }
	
  if (isObject(dashboardHud))
  { 
    echo("ThunderSword Hud Online.");
    pilotHudCreate();
	    clientCmdStartBomberSight();
	  }
  reticleHud.setBitmap("gui/hud_ret_thunder");
  
	
}

function endBomber()
{	
	  if (isObject(vDeltaAltText))
	  { pilotHudDestroy();
	    echo("ThunderSword Hud Offline.");
	    clientCmdEndBomberSight();
	    if ($ladderSchedule != 0) cancel($ladderSchedule);
	    if ($hoverTimer != 0) cancel($hoverTimer);
    $bomberHudCreate = false;
	  }
}

function startPassengerHud()
{  
       
           dashboardHud.speedBox = new HudBitmapCtrl(vBomberSpeedBox) {
               profile = "GuiDashBoxProfile";
               horizSizing = "right";
               vertSizing = "top";
               position = "210 61";
               extent = "68 32";
               minExtent = "8 8";
               bitmap = "gui/hud_veh_new_dashpiece_6";
               visible = "1";
               opacity = "0.8";

               new GuiTextCtrl(vSpeedText) {
                  profile = "GuiDashTextProfile";
                  horizSizing = "right";
                  vertSizing = "top";
                  position = "17 5";
                  extent = "18 15";
                  minExtent = "8 8";
                  visible = "1";
                  text = "test";
               };
               new GuiTextCtrl(vSpeedTxtLbl) {
                  profile = "GuiDashTextProfile";
                  horizSizing = "right";
                  vertSizing = "top";
                  position = "38 5";
                  extent = "18 15";
                  minExtent = "8 8";
                  visible = "1";
                  text = "KPH";
               };
            };
    
            dashboardHud.altBox = new HudBitmapCtrl(vAltitudeBox) {
               profile = "GuiDashBoxProfile";
               horizSizing = "right";
               vertSizing = "top";
               position = "361 61";
               extent = "68 32";
               minExtent = "8 8";
               bitmap = "gui/hud_veh_new_dashpiece_7";
               visible = "1";
               opacity = "0.8";

               new GuiTextCtrl(vAltitudeText) {
                  profile = "GuiDashTextProfile";
                  horizSizing = "right";
                  vertSizing = "top";
                  position = "19 5";
                  extent = "18 15";
                  minExtent = "8 8";
                  visible = "1";
                  text = "test";
               };
               new GuiTextCtrl(vAltitudeTxtLbl) {
                  profile = "GuiDashTextProfile";
                  horizSizing = "right";
                  vertSizing = "top";
                  position = "40 5";
                  extent = "12 15";
                  minExtent = "8 8";
                  visible = "1";
                  text = "M";
               };
            };
            dashboardHud.add(dashboardHud.speedBox);
            dashboardHud.updateSpeed();
            dashboardHud.add(dashboardHud.altBox);
            dashboardHud.updateAltitude();
}


function endPassengerHud()
{ vBomberSpeedBox.delete();
  vAltitudeBox.delete();
  cancel(dashboardHud.speedCheck);
  cancel(dashboardHud.altitudeCheck);
  
}

function startBombardierHud()
{ 
   new GuiTextCtrl(vWarningText) {
           profile = "GuiRWrnTextProfile";
           horizSizing = "center";
           vertSizing = "top";
           position = "360 37";
           extent = "100 15";
           minExtent = "8 8";
           visible = "1";
           text = "";
   };

   new GuiTextCtrl(vWrnBombText) {
           profile = "GuiRWrnTextProfile";
           horizSizing = "center";
           vertSizing = "top";
           position = "180 37";
           extent = "100 15";
           minExtent = "8 8";
           visible = "1";
           text = "";
   };
   dashboardHud.add(vWarningText);
   dashboardHud.add(vWrnBombText);             
   bombardierHudUpdate();
}

function bombardierHudUpdate()
{ if ($bombardierUpdate) cancel($bombardierUpdate);  

  if ($rdrAlarm || $testAlarm)
	  {  if ($rdrToggle)
	     { vWarningText.setValue("RADAR WARNING");
	       $rdrToggle = false;
	     }
     else
	     { vWarningText.setValue("");
	       $rdrToggle = true;
	     }
  }
	  else
	  { vWarningText.setValue("");
	    $rdrToggle = true;
	  }
	
  
	  if (getControlObjectAltitude() < 50 || $testAlarm)
	  { if ($bombToggle)
    { vWrnBombText.setValue("BOMB WARNING");
      $bombToggle = false;
    }
    else
	    { vWrnBombText.setValue("");
	      $bombToggle = true;
	    }
  }
	  else
	  { vWrnBombText.setValue("");
	    $bombToggle = true;
	  }
	  	
  $bombardierUpdate = schedule(200, 0, bombardierHudUpdate);
}



function endBombardierHud()
{
  if (isObject(vWarningText))
    vWarningText.delete();
  if (isObject(vWrnBombText))
    vWrnBombText.delete();
  if ($bombardierUpdate) cancel($bombardierUpdate);

}



function pilotHudHelp()
{ if (!$helpOpened)
  { clientCmdBottomPrint("key 0: toggles Hover\nkey -: decrease Hover alt\nkey +: increase Hover alt", 10, 3);
    $helpOpened = schedule(10000, 0, bomberHudHelp);
  }
  else
  { clientCmdBottomPrint("Left guage: acceleration (in km/h*s))\nRight guage: Altitude rate of change (M/sec, Alt is agl)", 10, 3);
    cancel($helpOpened);
    $helpOpened = 0;
  }
}


function autoPilot()
{   if ($bomberHudCreate)    
    { 
      if (!$autoPilot)
      { 
        $autoPilot = true;
        addMessageHudLine("Autopilot On.");
      }
      else
      { 
        $autoPilot = false;
        addMessageHudLine("Autopilot Off.");
      }
    }
}

function apUp()
{     if ($autoPilot)
        $mvPitch = $apAdj;
}

function hover()
{   if ($bomberHudCreate)  
    { if ($hover)
      { $hover = false;
        if ($hoverTimer != 0) cancel($hoverTimer);
        vStatusText.setValue("");  
      }
      else
      { $hover = true;
        hoverUpdate(); 
        $hoverStartAlt = getControlObjectAltitude();
      }
    }  
}  

function hoverUp(%val)
{   if ($bomberHudCreate)
    { $hover = true;
      hoverUpdate();
      $hoverStartAlt += 5;
      vStatusText.setValue("ALT: " @ $hoverStartAlt @ " M");
    }  
    echo(%val);
}

function hoverDown()
{   if ($bomberHudCreate) 
    { $hover = true;
      hoverUpdate();
      if ($hoverStartAlt > 15)
        $hoverStartAlt -= 5;
      vStatusText.setValue("ALT: " @ $hoverStartAlt @ " M");
    }
}


function hoverUpdate()
{     
      if ($hover)
      { 
        %currAlt = getControlObjectAltitude();
	        %alt = %currAlt - $hoverAlt;
	        $hoverAlt = %currAlt;
	        %spd = getControlObjectSpeed() * 3.6;
	
        if (%spd < $hSpdSens && mabs($mvPitch) < $hPitchSens)
        { if (($hoverStartAlt - %currAlt > 2) || (%alt < 0 && $hoverStartAlt > %currAlt))
          { $mvTriggerCount3 = 1;
            $jetsFiring = true;
          }
          else
          { $mvTriggerCount3 = 0;
            $jetsFiring = false;
          }
        
          if ($statusToggle)
          { vStatusText.setValue("HOVER MODE");
            $statusToggle = false;
          }
          else 
          { vStatusText.setValue("");
            $statusToggle = true;
          }
        }
        else
        { if ($jetsFiring)
          { $jetsFiring = false;
            $mvTriggerCount3 = 0;
          }
          vStatusText.setValue("");
          $hoverStartAlt = %currAlt;
        }    
         
        
        if ($hoverTimer != 0) cancel($hoverTimer);
        $hoverTimer = schedule(200, 0, hoverUpdate);
      
      }  
      
      else
      { vStatusText.setValue("");
        if ($hoverTimer != 0) cancel($hoverTimer);
      }
      
}

function SensorHud::update(%this)  
{  if(%this.ping)
   { $rdrAlarm = true;
   }
   else
   { $rdrAlarm = false;
   }
   //echo("update");
      
   Parent::update(%this);
}



// MAIN CALCULATIONS

function calculate()
{	if ($display)
	{  
	   %currAlt = getControlObjectAltitude();
	   %alt = (%currAlt - $oldAlt) * 5;
	   $oldAlt = %currAlt;
	   
	   %currSpd = getControlObjectSpeed() * 3.6;
	   %spd = %currSpd - $oldSpd;
	   $oldSpd = %currSpd;
	
	   if (%alt < -20)
	   { $count++;
	     $apAdj = %alt;
	     if ($count > 2)
	       $altAlarm = true;
	   }
	   else
	   { $count = 0;  
	     $altAlarm = false;
	     $apAdj = 0.005;
	   }

   if (%currAlt < 50)
     $bombAlarm = true;
   else
     $bombAlarm = false;
	   
	   if (%spd > 2 && %currSpd > 150)
	   { $spdAlarm = true;
	     $apAdj = %spd / -10;
	   }
	   else
	   { $spdAlarm = false;
	     $apAdj = 0.005;
	   }

   if (%currSpd < 200 && %currSpd > 25)
     $lowSpdAlarm = true;
   else
     $lowSpdAlarm = false; 
	   
           $playerAngle = mabs(%alt) @ "         ";
	   $playerAccel = mabs(%spd) * 5 @ "        ";
	   
	   
	   if (%alt < 0)
	     $altDir = "-"; 
	   else if (%alt > 0)
	     $altDir = "+"; 
	   else 
	     $altDir = "L"; 
	   
	   if (%spd < 0)
	     $spdDir = "-"; 
	   else if (%spd > 0)
	     $spdDir = "+"; 
	   else 
	   { $spdDir = "";
	     $playerAccel = "0.00";
	   }
	    
	   
	 }   // end if
	 else
	 { $playerAngle = "ERR";
	   $altDir = "E";
	   $playerAccel = "ERR";
	   $spdDir = "E";
	 }
	 	 
}

// TIMER

function ladderUpdate()
{
	if ($ladderSchedule != 0) cancel($ladderSchedule);
		
	calculate(); 
reticleHud.setBitmap("gui/hud_ret_thunder"); // cc messes up this reticle 
        vDeltaAltText.setValue(getSubStr($playerAngle,0,4));
	vDeltaAltTxtLbl.setValue($altDir);	
	
	vDeltaSpdText.setValue(getSubStr($playerAccel,0,4));
	vDeltaSpdTxtLbl.setValue($spdDir);	
	
	
	if ($rdrAlarm || $testAlarm)
	{  if ($rdrToggle)
	   { vWarningText.setValue("RADAR WARNING");
	     $rdrToggle = false;
	   }
	   else
	   { vWarningText.setValue("");
	     $rdrToggle = true;
	   }
	   
	}
	else
	{ vWarningText.setValue("");
	}
	
	if ($bombAlarm || $altAlarm || $testAlarm)
	{  if ($altToggle)
	   { if ($bombAlarm)
       vWrnAltText.setValue("BOMB WARNING");
     else
       vWrnAltText.setValue("ALTITUDE");
	     $altToggle = false;
	     apUp();
	   }
	   else
	   { vWrnAltText.setValue("");
	     $altToggle = true;
	   }
	   
	}
	else
	{ vWrnAltText.setValue("");
	}
	
	if ($spdAlarm || $lowSpdAlarm || $testAlarm)
	{  if ($spdToggle)
	   { if ($lowSpdAlarm)
       vWrnSpdText.setValue("LOW SPEED");
     else
       vWrnSpdText.setValue("HI ACCELERATION");
     $spdToggle = false;
	     apUp();
	   }
	   else
	   { vWrnSpdText.setValue("");
	     $spdToggle = true;
	   }
	   
	}
	else
	{ vWrnSpdText.setValue("");
	}
	
	$ladderSchedule = schedule(200, 0, ladderUpdate);
}       


// GUI

function pilotHudCreate()
{       
	if (isObject(vDeltaAltText))
	  pilotHudDestroy();
	  calculate();
	  $pilotHud = true;
	  echo("Initiating Ladder Hud...");  
 	 dashboardHud.deltaAltBox = new HudBitmapCtrl(vDeltaAltBox) {
            profile = "GuiDashBoxProfile";
            horizSizing = "right";
            vertSizing = "top";
            position = "357 26";
            extent = "80 25";
            minExtent = "8 8";
            bitmap = "gui/hud_veh_new_dashpiece_2";
            visible = "1";
            opacity = "0.8";

	         new GuiTextCtrl(vDeltaAltText) {
               profile = "GuiHudTextProfile";
               horizSizing = "right";
               vertSizing = "top";
               position = "22 5";
               extent = "40 15";
               minExtent = "8 8";
               visible = "1";
            };


            new GuiTextCtrl(vDeltaAltTxtLbl) {
               profile = "GuiHudTextProfile";
               horizSizing = "right";
               vertSizing = "top";
               position = "43 5";
               extent = "40 15";
               minExtent = "8 8";
               visible = "1";
               text = "^";
            };
            
        };
         
        dashboardHud.deltaSpdBox = new HudBitmapCtrl(vDeltaSpdBox) {
            profile = "GuiDashBoxProfile";
            horizSizing = "right";
            vertSizing = "top";
            position = "202 26";
            extent = "80 25";
            minExtent = "8 8";
            bitmap = "gui/hud_veh_new_dashpiece_3";
            visible = "1";
            opacity = "0.8";

	    new GuiTextCtrl(vDeltaSpdText) {
               profile = "GuiHudTextProfile";
               //horizSizing = "left";
               vertSizing = "top";
               position = "20 5";
               extent = "40 15";
               minExtent = "8 8";
               visible = "1";
               text = "350";
            };


            new GuiTextCtrl(vDeltaSpdTxtLbl) {
               profile = "GuiHudTextProfile";
               horizSizing = "right";
               vertSizing = "top";
               position = "0 5";
               extent = "40 15";
               minExtent = "8 8";
               visible = "1";
               text = "+";
            };
            
         };
        
         
         new GuiTextCtrl(vWarningText) {
           profile = "GuiGWrnTextProfile";
           horizSizing = "center";
           vertSizing = "top";
           position = "360 12";
           extent = "100 15";
           minExtent = "8 8";
           visible = "1";
           text = "";
         };
         
         new GuiTextCtrl(vStatusText) {
           profile = "GuiGWrnTextProfile";
           horizSizing = "center";
           vertSizing = "top";
           position = "180 12";
           extent = "100 15";
           minExtent = "8 8";
           visible = "1";
           text = "";
         };
        
         new GuiTextCtrl(vWrnAltText) {
           profile = "GuiRWrnTextProfile";
           horizSizing = "center";
           vertSizing = "top";
           position = "360 0";
           extent = "100 15";
           minExtent = "8 8";
           visible = "1";
           text = "";
         };
         
         new GuiTextCtrl(vWrnSpdText) {
           profile = "GuiRWrnTextProfile";
           horizSizing = "center";
           vertSizing = "top";
           position = "180 0";
           extent = "100 15";
           minExtent = "8 8";
           visible = "1";
           text = "";
         };
                
        
         dashboardHud.add(dashboardHud.deltaAltBox);  
         dashboardHud.add(dashboardHud.deltaSpdBox);      
         dashboardHud.add(vWarningText);
         dashboardHud.add(vStatusText);
	         dashboardHud.add(vWrnAltText);
         dashboardHud.add(vWrnSpdText);
	
         
         ladderUpdate();
}

function pilotHudDestroy()
{      	if ($ladderSchedule != 0) cancel($ladderSchedule);

	if ($pilotHud)
	{ dashboardHud.deltaAltBox.delete();
	  dashboardHud.deltaSpdBox.delete();
	  vWarningText.delete();
	  vStatusText.delete();
	  vWrnAltText.delete();
	  vWrnSpdText.delete();
	}
}

function PlayGui::onWake(%this)
{ 	if (!$bomberHudCreate)
	  {       
	    exec("gui/bomberHud.gui");
		  $bomberHudCreate = true;
  	}
	  parent::onWake(%this);
}


}; // end package
activatePackage(bomberHud);
echo("VeCTeR's BomberHud V1.0 Active");









































